==> libcommons-compress-java_1.21.orig.tar.xz: commons-compress-1.21-src/src/test/java/org/apache/commons/compress/compressors/zstandard/ZstdRoundtripTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.commons.compress.compressors.zstandard;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.nio.file.Files;

import org.apache.commons.compress.AbstractTestCase;
import org.apache.commons.compress.compressors.CompressorInputStream;
import org.apache.commons.compress.compressors.CompressorOutputStream;
import org.apache.commons.compress.compressors.CompressorStreamFactory;
import org.apache.commons.compress.utils.IOUtils;
import org.junit.Assert;
import org.junit.Test;

public class ZstdRoundtripTest extends AbstractTestCase {

    private interface OutputStreamCreator {
        ZstdCompressorOutputStream wrap(FileOutputStream os) throws IOException;
    }

    @Test
    public void directRoundtrip() throws Exception {
        roundtrip(ZstdCompressorOutputStream::new);
    }

    private void roundtrip(final OutputStreamCreator oc) throws IOException {
        final File input = getFile("bla.tar");
        long start = System.currentTimeMillis();
        final File output = new File(dir, input.getName() + ".zstd");
        try (InputStream is = Files.newInputStream(input.toPath());
             FileOutputStream os = new FileOutputStream(output);
             ZstdCompressorOutputStream zos = oc.wrap(os)) {
            IOUtils.copy(is, zos);
        }
        System.err.println(input.getName() + " written, uncompressed bytes: " + input.length()
            + ", compressed bytes: " + output.length() + " after " + (System.currentTimeMillis() - start) + "ms");
        start = System.currentTimeMillis();
        try (InputStream is = Files.newInputStream(input.toPath());
             ZstdCompressorInputStream zis = new ZstdCompressorInputStream(Files.newInputStream(output.toPath()))) {
            final byte[] expected = IOUtils.toByteArray(is);
            final byte[] actual = IOUtils.toByteArray(zis);
            Assert.assertArrayEquals(expected, actual);
        }
        System.err.println(output.getName() + " read after " + (System.currentTimeMillis() - start) + "ms");
    }

    @Test
    public void factoryRoundtrip() throws Exception {
        final File input = getFile("bla.tar");
        long start = System.currentTimeMillis();
        final File output = new File(dir, input.getName() + ".zstd");
        try (InputStream is = Files.newInputStream(input.toPath());
             OutputStream os = Files.newOutputStream(output.toPath());
             CompressorOutputStream zos = new CompressorStreamFactory().createCompressorOutputStream("zstd", os)) {
            IOUtils.copy(is, zos);
        }
        start = System.currentTimeMillis();
        try (InputStream is = Files.newInputStream(input.toPath());
             CompressorInputStream zis = new CompressorStreamFactory()
             .createCompressorInputStream("zstd", Files.newInputStream(output.toPath()))) {
            final byte[] expected = IOUtils.toByteArray(is);
            final byte[] actual = IOUtils.toByteArray(zis);
            Assert.assertArrayEquals(expected, actual);
        }
    }

    @Test
    public void roundtripWithCustomLevel() throws Exception {
        roundtrip(os -> new ZstdCompressorOutputStream(os, 1));
    }

    @Test
    public void roundtripWithCloseFrameOnFlush() throws Exception {
        roundtrip(os -> new ZstdCompressorOutputStream(os, 3, true));
    }

    @Test
    public void roundtripWithChecksum() throws Exception {
        roundtrip(os -> new ZstdCompressorOutputStream(os, 3, false, true));
    }

}

==> libcommons-compress-java_1.22.orig.tar.xz: commons-compress-1.22-src/src/test/java/org/apache/commons/compress/compressors/zstandard/ZstdRoundtripTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.commons.compress.compressors.zstandard;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.nio.file.Files;

import org.apache.commons.compress.AbstractTestCase;
import org.apache.commons.compress.compressors.CompressorInputStream;
import org.apache.commons.compress.compressors.CompressorOutputStream;
import org.apache.commons.compress.compressors.CompressorStreamFactory;
import org.apache.commons.compress.utils.IOUtils;
import org.junit.Assert;
import org.junit.jupiter.api.Test;

public class ZstdRoundtripTest extends AbstractTestCase {

    private interface OutputStreamCreator {
        ZstdCompressorOutputStream wrap(FileOutputStream os) throws IOException;
    }

    @Test
    public void directRoundtrip() throws Exception {
        roundtrip(ZstdCompressorOutputStream::new);
    }

    private void roundtrip(final OutputStreamCreator oc) throws IOException {
        final File input = getFile("bla.tar");
        long start = System.currentTimeMillis();
        final File output = new File(dir, input.getName() + ".zstd");
        try (InputStream is = Files.newInputStream(input.toPath());
             FileOutputStream os = new FileOutputStream(output);
             ZstdCompressorOutputStream zos = oc.wrap(os)) {
            IOUtils.copy(is, zos);
        }
        //System.err.println(input.getName() + " written, uncompressed bytes: " + input.length()
        //    + ", compressed bytes: " + output.length() + " after " + (System.currentTimeMillis() - start) + "ms");
        start = System.currentTimeMillis();
        try (InputStream is = Files.newInputStream(input.toPath());
             ZstdCompressorInputStream zis = new ZstdCompressorInputStream(Files.newInputStream(output.toPath()))) {
            final byte[] expected = IOUtils.toByteArray(is);
            final byte[] actual = IOUtils.toByteArray(zis);
            Assert.assertArrayEquals(expected, actual);
        }
        // System.err.println(output.getName() + " read after " + (System.currentTimeMillis() - start) + "ms");
    }

    @Test
    public void factoryRoundtrip() throws Exception {
        final File input = getFile("bla.tar");
        long start = System.currentTimeMillis();
        final File output = new File(dir, input.getName() + ".zstd");
        try (InputStream is = Files.newInputStream(input.toPath());
             OutputStream os = Files.newOutputStream(output.toPath());
             CompressorOutputStream zos = new CompressorStreamFactory().createCompressorOutputStream("zstd", os)) {
            IOUtils.copy(is, zos);
        }
        start = System.currentTimeMillis();
        try (InputStream is = Files.newInputStream(input.toPath());
             CompressorInputStream zis = new CompressorStreamFactory()
             .createCompressorInputStream("zstd", Files.newInputStream(output.toPath()))) {
            final byte[] expected = IOUtils.toByteArray(is);
            final byte[] actual = IOUtils.toByteArray(zis);
            Assert.assertArrayEquals(expected, actual);
        }
    }

    @Test
    public void roundtripWithCustomLevel() throws Exception {
        roundtrip(os -> new ZstdCompressorOutputStream(os, 1));
    }

    @Test
    public void roundtripWithCloseFrameOnFlush() throws Exception {
        roundtrip(os -> new ZstdCompressorOutputStream(os, 3, true));
    }

    @Test
    public void roundtripWithChecksum() throws Exception {
        roundtrip(os -> new ZstdCompressorOutputStream(os, 3, false, true));
    }

}
